@@ -35,5 +35,5 @@ def send(chat, url, result, rotate=0):
 		return chat.bot.send_media_group(chat.id, group, timeout = 20*60)
 
 	if result.cap:
-		chat.send_message(cutCaption(result.cap, suffix, 4000), 
-			parse_mode='Markdown', timeout = 20*60)
\ No newline at end of file
+		return [chat.send_message(cutCaption(result.cap, suffix, 4000), 
+			parse_mode='Markdown', timeout = 20*60)]
\ No newline at end of file
